<?php

namespace Teknisa\CADEST\Factories;


use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;

class Ger10000SegmentoDeMercadoFactory {
    protected $connection;

    public function __construct($entityManager) {
        $this->connection = $entityManager->getConnection();
        date_default_timezone_set('America/Sao_Paulo');
    }

    public function getNvMaxProd() {
        $sql = "SELECT MAX(CDNVPRODUTO) AS CDNVPRODUTO 
                FROM PRODUTO
                WHERE IDPRODATIVPR = 'S'";
        
        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    }
    
    public function insereProdutoNivel($row) {
      
        $sql = "INSERT INTO NIVELPRODSEG
                (CDSEGMER, CDPRODUTO)
            VALUES
                (:P_CDSEGMER, :P_CDPRODUTO)";
                
        $params = array('P_CDSEGMER'    => $row['CDSEGMER'],
                        'P_CDPRODUTO'   => $row['CDPRODUTO']);
                       
        $std = $this->connection->prepare($sql);
        return $std->execute($params);

    }
    
    public function insereProdutoNivelSegmento($row) {
      
        $sql = "INSERT INTO PRODUTOSEG
              (CDPRODUTO, CDSEGMER)
              (SELECT P1.CDPRODUTO, :P_CDSEGMER
                FROM PRODUTO P1
                WHERE P1.CDARVPROD LIKE :P_CDARVPROD||'%'
                AND P1.CDNVPRODUTO            = :P_CDNVPRODUTO
                AND (NVL(P1.IDPRODATIVPR,'S') = 'S')
                AND NOT EXISTS
                  (SELECT P2.CDPRODUTO
                  FROM PRODUTOSEG P2
                  WHERE P2.CDSEGMER = :P_CDSEGMER
                  AND P2.CDPRODUTO  = P1.CDPRODUTO
                  )
              )";
                
        $params = array('P_CDSEGMER'    => $row['CDSEGMER'],
                        'P_CDARVPROD'   => $row['CDARVPROD'],
                        'P_CDNVPRODUTO' => $row['CDNVPRODUTO']);
                       
        $std = $this->connection->prepare($sql);
        return $std->execute($params);

    }
    
    public function deleteProdutoNivel($row) {
      
        $sql = "DELETE FROM NIVELPRODSEG
                WHERE REGEXP_LIKE (CDSEGMER, :P_CDSEGMER)
                AND REGEXP_LIKE (CDPRODUTO, :P_CDPRODUTO)";
                
        $params = array('P_CDSEGMER'    => $row['CDSEGMER'],
                        'P_CDPRODUTO'   => $row['CDPRODUTO']);
                       
        $std = $this->connection->prepare($sql);
        return $std->execute($params);

    }
    
    public function deleteProdutoNivelSegmento($row) {
      
        $sql = "DELETE FROM PRODUTOSEG
                 WHERE REGEXP_LIKE (CDSEGMER, :P_CDSEGMER)
                   AND CDPRODUTO IN (SELECT P.CDPRODUTO
                                       FROM PRODUTO P
                                      WHERE P.CDARVPROD LIKE :P_CDARVPROD||'%')";
                
        $params = array('P_CDSEGMER'    => $row['CDSEGMER'],
                        'P_CDARVPROD'   => $row['CDARVPROD']);
                       
        $std = $this->connection->prepare($sql);
        return $std->execute($params);

    }
    
    public function verificaNivelCadastrado($row){
        $sql = "SELECT N.CDPRODUTO,
                       N.CDSEGMER,
                       '1' AS ID
                FROM NIVELPRODSEG N,
                     PRODUTO P
                WHERE P.IDPRODATIVPR = 'S'
                  AND P.CDARVPROD LIKE (:P_CDARVPROD)||'%'
                  AND N.CDPRODUTO = P.CDPRODUTO
                  AND P.CDNVPRODUTO > :P_CDNVPRODUTO
                  AND N.CDSEGMER = :P_CDSEGMER
                UNION
                SELECT N.CDPRODUTO,
                       N.CDSEGMER,
                       '2' AS ID
                FROM NIVELPRODSEG N,
                     PRODUTO P
                WHERE P.IDPRODATIVPR = 'S'
                  AND :P_CDARVPROD LIKE P.CDARVPROD||'%'
                  AND N.CDPRODUTO = P.CDPRODUTO
                  AND P.CDNVPRODUTO < :P_CDNVPRODUTO
                  AND N.CDSEGMER = :P_CDSEGMER";
        
        $params = array('P_CDARVPROD'   => $row['CDARVPROD'],
                        'P_CDNVPRODUTO' => $row['CDNVPRODUTO'],
                        'P_CDSEGMER'    => $row['CDSEGMER']);
                        
                        // var_dump($params);die;
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function produtoPrecoCadastrado($row){
                
        $sql = "SELECT (NVL(IT.PRECO, 0) + NVL(ITCL.PRECO, 0) + NVL(ITCC.PRECO, 0)) AS PRECO
                FROM
                  (SELECT (NVL(IT.VRPRECITEM, 0) + NVL(IT.VRPRECITEMCL, 0)) AS PRECO,
                          IT.CDFILIAL
                   FROM ITEMPRECO IT,
                        PRODUTO P,
                        TABEVEND TV
                   WHERE (P.CDARVPROD LIKE :P_CDARVPROD ||'%')
                     AND (IT.CDFILIAL = :P_CDFILIAL)
                     AND (P.CDPRODUTO = IT.CDPRODUTO)
                     AND (IT.CDFILIAL = TV.CDFILIAL)
                     AND (IT.CDTABEPREC = TV.CDTABEPREC)
                     AND (IT.DTINIVGPREC BETWEEN TV.DTINIVGPREC AND TV.DTFINVGPREC)) IT,
                
                  (SELECT (NVL(IT.VRPRCLITEM, 0) + NVL(IT.VRPRCLITEMCL, 0)) AS PRECO,
                          IT.CDFILIAL
                   FROM ITEMPRECOCLI IT,
                        PRODUTO P,
                        TABEVEND TV
                   WHERE (P.CDARVPROD LIKE :P_CDARVPROD ||'%')
                     AND (IT.CDFILIAL = :P_CDFILIAL)
                     AND (P.CDPRODUTO = IT.CDPRODUTO)
                     AND (IT.CDFILIAL = TV.CDFILIAL)
                     AND (IT.CDTABEPREC = TV.CDTABEPREC)
                     AND (IT.DTINIVGPREC BETWEEN TV.DTINIVGPREC AND TV.DTFINVGPREC)) ITCL,
                
                  (SELECT (NVL(IT.VRPRCONITE, 0) + NVL(IT.VRPRCONITECL, 0)) AS PRECO,
                          IT.CDFILIAL
                   FROM ITEMPRECOCON IT,
                        PRODUTO P,
                        TABEVEND TV
                   WHERE (P.CDARVPROD LIKE :P_CDARVPROD ||'%')
                     AND (IT.CDFILIAL = :P_CDFILIAL)
                     AND (P.CDPRODUTO = IT.CDPRODUTO)
                     AND (IT.CDFILIAL = TV.CDFILIAL)
                     AND (IT.CDTABEPREC = TV.CDTABEPREC)
                     AND (IT.DTINIVGPREC BETWEEN TV.DTINIVGPREC AND TV.DTFINVGPREC)) ITCC
                WHERE (IT.CDFILIAL = ITCL.CDFILIAL(+))
                  AND (IT.CDFILIAL = ITCC.CDFILIAL(+))";
        
        $params = array('P_CDFILIAL'    => $row['CDFILIAL'],
                        'P_CDARVPROD'   => $row['CDARVPROD']);
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
}